@@ -133,6 +133,7 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("labs/Chip.qml")), uri, 1, 3, "Chip");
     qmlRegisterType(componentUrl(QStringLiteral("labs/ContextualMenu.qml")), uri, 1, 3, "ContextualMenu");
     qmlRegisterType(componentUrl(QStringLiteral("labs/ComboBox.qml")), uri, 1, 3, "ComboBox");
+    qmlRegisterType(componentUrl(QStringLiteral("labs/FontsComboBox.qml")), uri, 1, 3, "FontsComboBox");
     qmlRegisterType(componentUrl(QStringLiteral("labs/TabView.qml")), uri, 1, 3, "TabView");
     qmlRegisterType(componentUrl(QStringLiteral("CloseButton.qml")), uri, 1, 3, "CloseButton");
     qmlRegisterType(componentUrl(QStringLiteral("labs/ColorsRow.qml")), uri, 1, 3, "ColorsRow");
@@ -146,6 +147,7 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("SearchField.qml")), uri, 1, 0, "SearchField");
     qmlRegisterType(componentUrl(QStringLiteral("PasswordField.qml")), uri, 1, 0, "PasswordField");
     qmlRegisterType(componentUrl(QStringLiteral("ScrollView.qml")), uri, 1, 0, "ScrollView");
+    qmlRegisterType(componentUrl(QStringLiteral("labs/StackView.qml")), uri, 1, 0, "StackView");
     
     /// NON UI CONTROLS
     qmlRegisterUncreatableType<AppView>(uri, 1, 1, "AppView", "Cannot be created AppView");
@@ -211,11 +213,7 @@ void MauiKit::registerTypes(const char *uri)
     qmlRegisterType<Notify>(uri, 1, 3, "Notify");
     qmlRegisterType<NotifyAction>(uri, 1, 3, "NotifyAction");
 
-    qmlRegisterSingletonType<Style>(uri, 1, 0, "Style", [] (QQmlEngine *, QJSEngine *)
-    {
-        return Style::instance ();
-    });
-
+    qmlRegisterUncreatableType<Style>(uri, 1, 0, "Style", "Cannot be created Style");
     qmlRegisterUncreatableType<MauiApp>(uri, 1, 0, "App", "Cannot be created App");
     qmlRegisterSingletonType<Handy>(uri, 1, 0, "Handy", [](QQmlEngine *, QJSEngine *)
     {
